# Step 4: Plan and Manage Risk Mitigation Initiatives
### On this page
  * [Conduct a Risk Remediation Analysis](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-plan-manage-mitigation#conduct-a-risk-remediation-analysis)
  * [Capture Risk Remediation Decisions](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-plan-manage-mitigation#capture-risk-remediation-decisions)
  * [Establish Risk Dispensation Program](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-plan-manage-mitigation#establish-risk-dispensation-program)
  * [Next Step](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-plan-manage-mitigation#next-step)


Conduct a risk remediation analysis, establish a risk dispensation program, and plan and run remediation efforts.
In this phase, identified risks are analyzed, and strategies are developed to reduce or eliminate their potential impact. This includes effective resource allocation and the implementation of proactive measures to mitigate identified risks.
